@@ -5,7 +5,7 @@ package Devel::Events::Objects;
 use strict;
 use warnings;
 
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 
 __PACKAGE__;
 
@@ -76,7 +76,7 @@ L<Catalyst::Plugin::LeakTracker> for a real world application of these classes.
 =head1 SEE ALSO
 
 L<Devel::Events>, L<Devel::Events::Filter::Size>,
-L<Catalsyt::Plugin::LeakTracker>, L<Devel::Cycle>, L<Devel::Leak::Object>
+L<Catalyst::Plugin::LeakTracker>, L<Devel::Cycle>, L<Devel::Leak::Object>
 
 =head1 AUTHOR
 
